#
# spec file for package codespell
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           codespell
VCS: https://src.suse.de/SLFO-pool/codespell#8ac9b87ec2a1af9efda656ac1e7ec50dabc388dcc347f290a63fe8990f41599d
Version:        2.2.4
Release:        160000.1.9
Summary:        Source code checker for common misspellings
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://github.com/codespell-project/codespell/
Source0:        https://github.com/codespell-project/codespell/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE - patch_version.patch
Patch0:         patch_version.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-chardet
BuildRequires:  python3-pip
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       python3-chardet
Requires:       python3-setuptools
BuildArch:      noarch

%description
codespell fixes common misspellings in text files. It primarily checks
misspelled words in source code, but it can be used with other files as well.

%prep
%setup -q
%patch0 -p1
# remove everything coverage-related
sed -i '/\-cov/ d' pyproject.toml

%build
%pyproject_wheel

%check
# disable command test; does not work in chroot
export PATH=$PATH:%{buildroot}%{_bindir}
%pytest -k 'not test_command'

%install
%pyproject_install
%fdupes %{buildroot}%{python3_sitelib}

%files
%license COPYING
%doc README.rst
%{_bindir}/codespell
%{python3_sitelib}/codespell_lib
%{python3_sitelib}/%{name}-%{version}.dist-info

%changelog
* Mon May 22 2023 jsrain@suse.com
- removed autogenerated _version.py
* Wed Mar 22 2023 sebix@sebix.at
- remove manpage as the build of the page no longer works
  it requires an executable file, which no longer is present
- add patch_version.patch to add the version to the lib
  - remove help2man-run-needs-utf8-locale.patch
- update to version 2.2.4:
  - BUG: Fix bug with toml triage (#2774)
- update to version 2.2.3:
  - Misspelling of sufficient, sufficiently by @vikivivi in #2531
  - insuffient->insufficient by @tkoyama010 in #2527
  - add anayltic(s|al|ally) -> analytic(s|al|ally) by @robin-wayve in #2507
  - Ignore flake8 rule W503 by @DimitriPapadopoulos in #2069
  - Dead code found by vulture by @DimitriPapadopoulos in #2101
  - Move falsy and accreting to more appropriate files by @janosh in #2511
  - Add subtrate->substrate by @janosh in #2525
  - Add "subtask" by @int-y1 in #2537
  - Apply pyupgrade to project by @jdufresne in #2364
  - {speherical,sperhical}->spherical by @janosh in #2540
  - interepolation->interpolation by @tkoyama010 in #2512
  - Ignore .mypy_cache folder by @kianmeng in #2361
  - Fix uncaught exception on unreadable files by @DimitriPapadopoulos in #2196
  - Add constrainst to dictionary by @jonathanberthias in #2546
  - Add relative hidden directory and basic subdir tests by @peternewman in #2542
  - Add trignometric->trigonometric by @janosh in #2549
  - Add virtualied->virtualized, virtualised and friends by @peternewman in #2553
  - Add several spelling corrections by @luzpaz in #2521
  - Slightly simplify some boolean expressions by @jdufresne in #2556
  - MAINT: Add CODEOWNERS by @larsoner in #2535
  - positivie->positive by @janosh in #2558
  - DOC/ENH: Clarify usage or configuration files and log about it by @sappelhoff in #2552
  - Document required setuptools version by @DimitriPapadopoulos in #2560
  - Redundant wheel dependency in pyproject.toml by @DimitriPapadopoulos in #2562
  - Remove parameterizes->parametrizes by @int-y1 in #2563
  - Replace codecs.open with open by @jdufresne in #2378
  - Update subprocess usage to use modern subprocess.run() by @jdufresne in #2565
  - Fix produce typo by @DimitriPapadopoulos in #2561
  - Add a few corrections by @int-y1 in #2566
  - Migrate pytest config into pyproject.toml by @cclauss in #2554
  - Handle bad globs passed to if --skip/-S by @DimitriPapadopoulos in #2159
  - Isn't the mailing list obsolete? by @DimitriPapadopoulos in #2090
  - More CODEOWNERS by @peternewman in #2569
  - Remove unused attribute Misspelling.fixword by @jdufresne in #2557
  - Read config file without interpolation by @DimitriPapadopoulos in #2545
  - Add andriod->android and friends by @peternewman in #2570
  - Add total type GB to US by @peternewman in #2577
  - Catch all cases of missing pytest by @DimitriPapadopoulos in #2568
  - Fix typo in README pin → pip by @DimitriPapadopoulos in #2579
  - Keep GitHub Actions up to date with Dependabot by @DimitriPapadopoulos in #2578
  - decelaration could be deceleration by @DimitriPapadopoulos in #2576
  - Add isort to project by @jdufresne in #2564
  - Fix Deepsource issues by @DimitriPapadopoulos in #2085
  - Replace list()/dict() with literals by @jdufresne in #2380
  - Use major version @v1 of isort GitHub Action by @DimitriPapadopoulos in #2581
  - Add a spelling correction by @fxlb in #2572
  - Remove obsolete Python 2 workaround by @jdufresne in #2586
  - Add misspelling of Kafka by @vikivivi in #2589
  - Add testing and document support for Python 3.11 by @jdufresne in #2585
  - Add type annotations to the project and use mypy by @jdufresne in #2588
  - Add a few spelling corrections by @int-y1 in #2550
  - Add several spelling corrections by @luzpaz in #2582
  - quation->equation by @janosh in #2591
  - Document support for Python versions in pyproject.toml by @jdufresne in #2379
  - Use black to format Python files by @jdufresne in #2587
  - Move "upto" to code dictionary by @skangas in #2603
  - Move sudo-like command name "doas" to code dictionary by @skangas in #2600
  - enthapl(ies|y)->enthalp(ies|y) by @janosh in #2590
  - Add componoent(s)->component(s) by @cfi-gb in #2594
  - Move "spawnve" to code dictionary by @skangas in #2614
  - Move "MSDOS" to code dictionary by @skangas in #2615
  - Added informal words by @Paradact in #2575
  - Improve format of CC BY-SA 3.0 license link by @skangas in #2619
  - {assymthotic, assymtotic}->asymptotic by @janosh in #2597
  - Simplify some file reading in tests by opening in text mode by @jdufresne in #2624
  - Remove setup.py by @jdufresne in #2626
  - Normalize code block indicators in README by @waldyrious in #2621
  - PEP 517 by @DimitriPapadopoulos in #2595
  - Add spelling correction for 'alhpa' by @adrien-berchet in #2627
  - Move Windows CI from AppVeyor to GitHub Actions by @jdufresne in #2628
  - Add "token" as alternative for "toke" by @skangas in #2630
  - Add spelling corrections for version. by @cfi-gb in #2629
  - feat: Add cataalogue->catalogue to dictionary by @matthewfeickert in #2631
  - Add several spelling corrections found in personal projects by @jdufresne in #2623
  - Add several words for en-GB to en-US by @skangas in #2598
  - Add fixes from misspell-fixer's safe.1.dict by @skangas in #2611
  - Prefer "converter" to "convertor" by @skangas in #2613
  - Add pre-commit configuration by @mdeweerd in #2459
  - pre-commit: check toml, rst, yml and .in files by @mdeweerd in #2636
  - centriod->centroid by @janosh in #2637
  - Add operatin->operation, operating, correction. by @cfi-gb in #2640
  - README: Document how to use pre-commit by @WilliamJamieson in #2639
  - README: document simplest usage pattern by @waldyrious in #2638
  - Prefer HTTPS to HTTP in URLs by @skangas in #2641
  - Flush stdout when asking word fix by @adrien-berchet in #2642
  - Correct "3rt" to "3rd" by @skangas in #2634
- update to version 2.2.2:
  - MAINT: Bump to dev by @larsoner in #2463
  - Capitalize LessTif by @dforsi in #2471
  - Add several spelling corrections by @ydah in #2467
  - aexs->axes by @tkoyama010 in #2475
  - MAINT: Add tests as submodule by @larsoner in #2477
  - diffues->diffuse, defuse, by @tkoyama010 in #2476
  - conviencece->convenience by @tkoyama010 in #2474
  - htose->those, these, by @tkoyama010 in #2480
  - Add several spelling corrections by @adrien-berchet in #2461
  - move ro to code dictionary by @robin-wayve in #2468
  - Add ascconciated->associated by @peternewman in #2482
  - Fix various spelling corrections by @luzpaz in #2456
  - Add several spelling corrections by @luzpaz in #2481
  - Add sorkflow->workflow by @peternewman in #2485
  - Add spelling corrections for install and variants. by @cfi-gb in #2486
  - Capitalize all suggested fixes by @DimitriPapadopoulos in #2223
  - Add several spelling corrections and refinements by @luzpaz in #2484
  - Add knowladge->knowledge by @danielhoherd in #2493
  - Add several spelling corrections by @ydah in #2492
  - Change "circularly" to "circulary". by @vinc17fr in #2422
  - Use grep -E instead of egrep by @a1346054 in #2496
  - move warmup to code dictionary by @robin-wayve in #2495
  - downoload->download and friends by @DimitriPapadopoulos in #2494
  - Add some alternative line endings and whitespace checks by @peternewman in #2490
  - occulusion->occlusion by @tkoyama010 in #2502
  - Add another suggestion for relected by @vinc17fr in #2501
  - add dependendenc(y|ies)->dependenc(y|ies) by @robin-wayve in #2499
  - Add application(s) spelling corrections. by @cfi-gb in #2503
  - Add spelling correction for place by @adrien-berchet in #2500
  - Add spelling correction by @adrien-berchet in #2498
  - 'analyses' is the plural of 'analysis' by @quyykk in #2401
  - Add spelling corrections for dictionar(y|ies) by @cfi-gb in #2509
  - Add spelling correction for export by @adrien-berchet in #2506
  - Fix #2055: Add support for PEP 518 by @Freed-Wu in #2290
  - Add regresison->regression by @janosh in #2518
  - DOC: Better docs by @larsoner in #2515
  - Fix build_exclude_hashes fails: UnicodeDecodeError: 'charmap' codec can't decode byte 0x81 in position 2244: character maps to by @JoergAtGithub in #2520
  - Add alternative for 'bu' by @flyingdutchman23 in #2514
  - Add alternative for 'tooo' by @flyingdutchman23 in #2513
  - Fix uncaught exception on empty files by @DimitriPapadopoulos in #2195
  - Add combintaion(s)->combination(s) by @janosh in #2524
  - MAINT: Use pyproject and setuptools_scm by @larsoner in #2523
* Thu Aug 18 2022 mvetter@suse.com
- Update to 2.2.1:
  See https://github.com/codespell-project/codespell/compare/v2.2.0...v2.2.1
* Thu Aug 18 2022 mvetter@suse.com
- Update to 2.2.0:
  See https://github.com/codespell-project/codespell/compare/v2.1.0...v2.2.0
* Thu Jun 10 2021 mardnh@gmx.de
- Update to 2.1.0:
  * No upstream changelog
* Sun Nov 29 2020 mardnh@gmx.de
- Update to 2.0.0:
  * No upstream changelog
* Fri May 22 2020 mardnh@gmx.de
- Update to version 1.17.1:
  * Upstream does not provide a changelog
- Update patch:
  * help2man-run-needs-utf8-locale.patch
* Fri Sep 13 2019 mvetter@suse.com
- Update to 1.16.0:
  * Add several more spelling corrections
  * Fix typos
* Thu Jan 31 2019 tchvatal@suse.com
- Update to 1.14.0:
  * No upstream changelog
- Fix build under python 3.7
* Sat Jul 14 2018 jengelh@inai.de
- Use noun phrasing.
* Wed Jul  4 2018 psimons@suse.com
- update to 1.13.0 release
* Thu Feb  4 2016 sweet_f_a@gmx.de
- initial package 1.8.git31.gd4ba
